:mod:`langacore.kit.django.common.templatetags.bbcode`
======================================================


.. automodule:: langacore.kit.django.common.templatetags.bbcode


Functions
----------

.. autofunction:: bbcode

